@@ -50,8 +50,10 @@ def run_local_optimizer(d,x0,x_defl = []):
     Lg = np.empty((number_of_walkers, dim))
     eig = np.empty((number_of_walkers,dim))
     local_success = np.empty((number_of_walkers), dtype = bool)
+    messages = np.empty((number_of_walkers), dtype = str)
+
     for i in range(len(tasks)):
-        x[i],f[i],Lg[i],eig[i],local_success[i] = results[i]
+        x[i],f[i],Lg[i],eig[i],local_success[i], messages[i] = results[i]
         client.cancel(tasks[i])
         for j in range(i):
             if np.linalg.norm(np.subtract(x[i],x[j])) < 2.0 * d.radius and local_success[j] == True:
@@ -61,7 +63,7 @@ def run_local_optimizer(d,x0,x_defl = []):
             if np.linalg.norm(np.subtract(x[i],x_defl[j])) < 2.0 * d.radius and all(Lg[i] < 1e-5):
                 logger.warning("local method converged within 2 x radius of a deflated position in HGDL")
                 local_success[i] = False
-    return x, f, Lg, eig, local_success
+    return x, f, Lg, eig, local_success, messages
 
 def local_method(data, method = "dNewton"):
     from functools import partial
@@ -85,7 +87,7 @@ def local_method(data, method = "dNewton"):
 
     #call local methods
     if method == "dNewton":
-        x,L,Lg,eig,local_success = DNewton(d.L,Lgrad,Lhess,bounds,x0,max_iter,tol,*args)
+        x,L,Lg,eig,local_success,message = DNewton(d.L,Lgrad,Lhess,bounds,x0,max_iter,tol,*args)
         f = d.func(x,*args)
 
     elif type(method) == str:
@@ -99,7 +101,7 @@ def local_method(data, method = "dNewton"):
         local_success = res["success"]
 
     elif callable(method):
-        res = method(d.func,grad,hess,bounds,x0,*args)
+        res = method(d.func,Lgrad,Lhess,bounds,x0,*args)
         x = res["x"]
         f = res["fun"]
         eig = np.ones(x.shape) * np.nan
@@ -109,5 +111,5 @@ def local_method(data, method = "dNewton"):
 
     else: raise Exception("no local method specified")
 
-    return x,f,Lg,np.real(eig),local_success
+    return x,f,Lg,np.real(eig),local_success,message
 ###########################################################################
